@@ -17,7 +17,7 @@ import math
 import functools
 import zipfile
 import xlsxwriter
-from typing import Any, List, Union, NoReturn, Set, Type, Iterator, Callable
+from typing import Any, List, Union, NoReturn, Set, Type, Iterator, Callable, Tuple
 from numpy import ndarray
 from aitool.basic_function.basic import split_dict
 from aitool.basic_function.deduplication import Deduplication
@@ -369,7 +369,8 @@ def dump_panda(
 
     if 'index' in kwargs and isinstance(kwargs['index'], bool):
         raise ValueError('The parameter `index` is for pd.DataFrame. '
-                         'If want to set the `index` for panda.to_csv/excel please use `dump_index`')
+                         'If want to set the `index` for panda.to_csv/excel please use `dump_index`'
+                         'If want to hide the header please use `heade=None`')
     if file_format == 'excel':
         print('WARNING: default set header=False')
         kwargs['header'] = False if 'header' not in kwargs else kwargs['header']
@@ -409,7 +410,11 @@ dump_excel = functools.partial(dump_panda, file_format='excel')
 
 
 def load_excel(*args, to_list=False, **kwargs) -> Union[ndarray, Any]:
-    kwargs['engine'] = 'openpyxl' if 'engine' not in kwargs else kwargs['engine']
+    print(args[0])
+    if args[0][-4:] == '.xls':
+        kwargs['engine'] = 'xlrd' if 'engine' not in kwargs else kwargs['engine']
+    else:
+        kwargs['engine'] = 'openpyxl' if 'engine' not in kwargs else kwargs['engine']
     kwargs['keep_default_na'] = False if 'keep_default_na' not in kwargs else kwargs['keep_default_na']
 
     data = np.array([])
@@ -423,9 +428,11 @@ def load_excel(*args, to_list=False, **kwargs) -> Union[ndarray, Any]:
     return data
 
 
-def load_csv(*args, **kwargs) -> List:
+def load_csv(*args, to_list=False, **kwargs) -> Union[ndarray, Any]:
     df = pd.read_csv(*args, **kwargs)
-    data = df.values.tolist()
+    data = df.values
+    if to_list:
+        return data.tolist()
     return data
 
 
@@ -498,10 +505,18 @@ def prepare_data(url: str, directory: str = '', packed: bool = False, pack_way:
         unzip(packed_file, directory)
 
 
+def split_path(file_path: str) -> tuple[str, str, Any, Any]:
+    dir_name, full_file_name = os.path.split(file_path)
+    file_name, file_ext = os.path.splitext(full_file_name)
+    return dir_name, full_file_name, file_name, file_ext
+
+
 if __name__ == '__main__':
     # test_data = [[i] for i in range(26)]
     # test_file = 'tmp.xlsx'
     # dump_excel(test_data, test_file)
     # for text in load_big_data('A.log', separator=' '):
     #     print(text)
-    add_python_path('../', recursive=False, show=True)
+    # add_python_path('../', recursive=False, show=True)
+    # load_excel('a.xls')
+    print(split_path('./a/b.k.txt'))
